quantizationtools.QGrid
=======================

.. inheritance-diagram:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid
   :private-bases:

.. autoclass:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.definition

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.next

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.offsets

Methods
-------

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.find_divisible_indices

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.find_parentage_of_index

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.format_for_beatspan

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.subdivide_indices

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__eq__

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__getitem__

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__iter__

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__len__

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__repr__

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__setitem__

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__str__

   .. note:: Inherited from `__builtin__.object`
